/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/**
   @file defaults.h
   @brief Input defaults for TiRiFiC

   On the way to a more automated tirific, this module provides
   default values, for now starting with defaults for the fitting
   parameters.  Howto: For each of the parameters controlling the
   fitting process, PARMAX, PARMIN, MODERATE, DELSTART, DELEND,
   ITESTART, ITEEND, SATDELT, MINDELTA, a default is given. This
   default is overridden, if a parameter-specific default
   PARNAME_PARMAX ... is given.
   
*/
/* ------------------------------------------------------------ */



/* Include guard */
#ifndef TIRIFIC_DEFAULTS_H
#define TIRIFIC_DEFAULTS_H


/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* EXTERNAL INCLUDES */
/* ------------------------------------------------------------ */
#include <float.h>


/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* INTERNAL INCLUDES */
/* ------------------------------------------------------------ */



/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* SYMBOLIC CONSTANTS */
/* ------------------------------------------------------------ */

/* This is the sensible choice for velocity, let's use this as generic input */
#define TIRIFIC_DEF_PARMAX   DBL_MAX
#define TIRIFIC_DEF_PARMIN   (-DBL_MAX)
#define TIRIFIC_DEF_MODERATE 3
#define TIRIFIC_DEF_DELSTART 3
#define TIRIFIC_DEF_DELEND   1
#define TIRIFIC_DEF_ITESTART 100
#define TIRIFIC_DEF_ITEEND   100
#define TIRIFIC_DEF_SATDELT  0.2
#define TIRIFIC_DEF_MINDELTA 0.05

#define TIRIFIC_DEF_PARMAX_VROT TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_VRAD TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_VVER TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_DVRO TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_DVRA TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_DVVE TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_ZDRO TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_ZDRA TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_ZDVE TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_Z0   TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_SBR  TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_SM1A TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_SM1P TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_SM2A TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_SM2P TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_SM3A TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_SM3P TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_SM4A TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_SM4P TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_GA1A TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_GA1P TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_GA1D TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_GA2A TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_GA2P TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_GA2D TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_GA3A TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_GA3P TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_GA3D TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_GA4A TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_GA4P TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_GA4D TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_AZ1P TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_AZ1W TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_AZ2P TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_AZ2W TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_INCL TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_PA   TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_XPOS TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_YPOS TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_VSYS TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_SDIS TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_CLNR TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_VM0A TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_VM1A TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_VM1P TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_VM2A TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_VM2P TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_VM3A TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_VM3P TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_VM4A TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_VM4P TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_WM0A TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_WM1A TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_WM1P TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_WM2A TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_WM2P TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_WM3A TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_WM3P TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_WM4A TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_WM4P TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_LS0  TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_LC0  TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_RO1A TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_RO1P TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_RO2A TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_RO2P TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_RO3A TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_RO3P TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_RO4A TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_RO4P TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_RA1A TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_RA1P TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_RA2A TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_RA2P TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_RA3A TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_RA3P TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_RA4A TIRIFIC_DEF_PARMAX
#define TIRIFIC_DEF_PARMAX_RA4P TIRIFIC_DEF_PARMAX

#define TIRIFIC_DEF_PARMIN_VROT TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_VRAD TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_VVER TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_DVRO TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_DVRA TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_DVVE TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_ZDRO TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_ZDRA TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_ZDVE TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_Z0   TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_SBR  TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_SM1A TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_SM1P TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_SM2A TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_SM2P TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_SM3A TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_SM3P TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_SM4A TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_SM4P TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_GA1A TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_GA1P TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_GA1D TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_GA2A TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_GA2P TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_GA2D TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_GA3A TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_GA3P TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_GA3D TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_GA4A TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_GA4P TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_GA4D TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_AZ1P TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_AZ1W TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_AZ2P TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_AZ2W TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_INCL TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_PA   TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_XPOS TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_YPOS TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_VSYS TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_SDIS TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_CLNR TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_VM0A TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_VM1A TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_VM1P TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_VM2A TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_VM2P TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_VM3A TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_VM3P TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_VM4A TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_VM4P TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_WM0A TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_WM1A TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_WM1P TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_WM2A TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_WM2P TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_WM3A TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_WM3P TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_WM4A TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_WM4P TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_LS0  TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_LC0  TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_RO1A TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_RO1P TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_RO2A TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_RO2P TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_RO3A TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_RO3P TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_RO4A TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_RO4P TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_RA1A TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_RA1P TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_RA2A TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_RA2P TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_RA3A TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_RA3P TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_RA4A TIRIFIC_DEF_PARMIN
#define TIRIFIC_DEF_PARMIN_RA4P TIRIFIC_DEF_PARMIN

#define TIRIFIC_DEF_PARMAX_PSWARM_VROT 500
#define TIRIFIC_DEF_PARMAX_PSWARM_VRAD 500
#define TIRIFIC_DEF_PARMAX_PSWARM_VVER 500
#define TIRIFIC_DEF_PARMAX_PSWARM_DVRO 50
#define TIRIFIC_DEF_PARMAX_PSWARM_DVRA 50
#define TIRIFIC_DEF_PARMAX_PSWARM_DVVE 50
#define TIRIFIC_DEF_PARMAX_PSWARM_ZDRO 500
#define TIRIFIC_DEF_PARMAX_PSWARM_ZDRA 500
#define TIRIFIC_DEF_PARMAX_PSWARM_ZDVE 500
#define TIRIFIC_DEF_PARMAX_PSWARM_Z0   50000
#define TIRIFIC_DEF_PARMAX_PSWARM_SBR  1E-2
#define TIRIFIC_DEF_PARMAX_PSWARM_SM1A 1E-2
#define TIRIFIC_DEF_PARMAX_PSWARM_SM1P 360
#define TIRIFIC_DEF_PARMAX_PSWARM_SM2A 1E-2
#define TIRIFIC_DEF_PARMAX_PSWARM_SM2P 360
#define TIRIFIC_DEF_PARMAX_PSWARM_SM3A 1E-2
#define TIRIFIC_DEF_PARMAX_PSWARM_SM3P 360
#define TIRIFIC_DEF_PARMAX_PSWARM_SM4A 1E-2
#define TIRIFIC_DEF_PARMAX_PSWARM_SM4P 360
#define TIRIFIC_DEF_PARMAX_PSWARM_GA1A 1E-2
#define TIRIFIC_DEF_PARMAX_PSWARM_GA1P 360
#define TIRIFIC_DEF_PARMAX_PSWARM_GA1D 360
#define TIRIFIC_DEF_PARMAX_PSWARM_GA2A 1E-2
#define TIRIFIC_DEF_PARMAX_PSWARM_GA2P 360
#define TIRIFIC_DEF_PARMAX_PSWARM_GA2D 360
#define TIRIFIC_DEF_PARMAX_PSWARM_GA3A 1E-2
#define TIRIFIC_DEF_PARMAX_PSWARM_GA3P 360
#define TIRIFIC_DEF_PARMAX_PSWARM_GA3D 360
#define TIRIFIC_DEF_PARMAX_PSWARM_GA4A 1E-2
#define TIRIFIC_DEF_PARMAX_PSWARM_GA4P 360
#define TIRIFIC_DEF_PARMAX_PSWARM_GA4D 360
#define TIRIFIC_DEF_PARMAX_PSWARM_AZ1P 360
#define TIRIFIC_DEF_PARMAX_PSWARM_AZ1W 360
#define TIRIFIC_DEF_PARMAX_PSWARM_AZ2P 360
#define TIRIFIC_DEF_PARMAX_PSWARM_AZ2W 360
#define TIRIFIC_DEF_PARMAX_PSWARM_INCL 180
#define TIRIFIC_DEF_PARMAX_PSWARM_PA   360
#define TIRIFIC_DEF_PARMAX_PSWARM_XPOS 720
#define TIRIFIC_DEF_PARMAX_PSWARM_YPOS 180
#define TIRIFIC_DEF_PARMAX_PSWARM_VSYS 100000
#define TIRIFIC_DEF_PARMAX_PSWARM_SDIS 100
#define TIRIFIC_DEF_PARMAX_PSWARM_CLNR 1000
#define TIRIFIC_DEF_PARMAX_PSWARM_VM0A 500
#define TIRIFIC_DEF_PARMAX_PSWARM_VM1A 500
#define TIRIFIC_DEF_PARMAX_PSWARM_VM1P 360
#define TIRIFIC_DEF_PARMAX_PSWARM_VM2A 500
#define TIRIFIC_DEF_PARMAX_PSWARM_VM2P 360
#define TIRIFIC_DEF_PARMAX_PSWARM_VM3A 500
#define TIRIFIC_DEF_PARMAX_PSWARM_VM3P 360
#define TIRIFIC_DEF_PARMAX_PSWARM_VM4A 500
#define TIRIFIC_DEF_PARMAX_PSWARM_VM4P 360
#define TIRIFIC_DEF_PARMAX_PSWARM_WM0A 10000
#define TIRIFIC_DEF_PARMAX_PSWARM_WM1A 10000
#define TIRIFIC_DEF_PARMAX_PSWARM_WM1P 360
#define TIRIFIC_DEF_PARMAX_PSWARM_WM2A 10000
#define TIRIFIC_DEF_PARMAX_PSWARM_WM2P 360
#define TIRIFIC_DEF_PARMAX_PSWARM_WM3A 10000
#define TIRIFIC_DEF_PARMAX_PSWARM_WM3P 360
#define TIRIFIC_DEF_PARMAX_PSWARM_WM4A 10000
#define TIRIFIC_DEF_PARMAX_PSWARM_WM4P 360
#define TIRIFIC_DEF_PARMAX_PSWARM_LS0  10000
#define TIRIFIC_DEF_PARMAX_PSWARM_LC0  10000
#define TIRIFIC_DEF_PARMAX_PSWARM_RO1A 500
#define TIRIFIC_DEF_PARMAX_PSWARM_RO1P 360
#define TIRIFIC_DEF_PARMAX_PSWARM_RO2A 500
#define TIRIFIC_DEF_PARMAX_PSWARM_RO2P 360
#define TIRIFIC_DEF_PARMAX_PSWARM_RO3A 500
#define TIRIFIC_DEF_PARMAX_PSWARM_RO3P 360
#define TIRIFIC_DEF_PARMAX_PSWARM_RO4A 500
#define TIRIFIC_DEF_PARMAX_PSWARM_RO4P 360
#define TIRIFIC_DEF_PARMAX_PSWARM_RA1A 500
#define TIRIFIC_DEF_PARMAX_PSWARM_RA1P 360
#define TIRIFIC_DEF_PARMAX_PSWARM_RA2A 500
#define TIRIFIC_DEF_PARMAX_PSWARM_RA2P 360
#define TIRIFIC_DEF_PARMAX_PSWARM_RA3A 500
#define TIRIFIC_DEF_PARMAX_PSWARM_RA3P 360
#define TIRIFIC_DEF_PARMAX_PSWARM_RA4A 500
#define TIRIFIC_DEF_PARMAX_PSWARM_RA4P 360  

#define TIRIFIC_DEF_PARMIN_PSWARM_VROT 0  
#define TIRIFIC_DEF_PARMIN_PSWARM_VRAD -500  
#define TIRIFIC_DEF_PARMIN_PSWARM_VVER -500  
#define TIRIFIC_DEF_PARMIN_PSWARM_DVRO -50   
#define TIRIFIC_DEF_PARMIN_PSWARM_DVRA -50   
#define TIRIFIC_DEF_PARMIN_PSWARM_DVVE -50   
#define TIRIFIC_DEF_PARMIN_PSWARM_ZDRO 0  
#define TIRIFIC_DEF_PARMIN_PSWARM_ZDRA 0  
#define TIRIFIC_DEF_PARMIN_PSWARM_ZDVE 0  
#define TIRIFIC_DEF_PARMIN_PSWARM_Z0   0.0001
#define TIRIFIC_DEF_PARMIN_PSWARM_SBR  0 
#define TIRIFIC_DEF_PARMIN_PSWARM_SM1A 0 
#define TIRIFIC_DEF_PARMIN_PSWARM_SM1P -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_SM2A 0 
#define TIRIFIC_DEF_PARMIN_PSWARM_SM2P -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_SM3A 0 
#define TIRIFIC_DEF_PARMIN_PSWARM_SM3P -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_SM4A 0 
#define TIRIFIC_DEF_PARMIN_PSWARM_SM4P -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_GA1A 0 
#define TIRIFIC_DEF_PARMIN_PSWARM_GA1P -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_GA1D 0.0001  
#define TIRIFIC_DEF_PARMIN_PSWARM_GA2A 0 
#define TIRIFIC_DEF_PARMIN_PSWARM_GA2P -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_GA2D 0.0001
#define TIRIFIC_DEF_PARMIN_PSWARM_GA3A 0 
#define TIRIFIC_DEF_PARMIN_PSWARM_GA3P -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_GA3D 0.0001  
#define TIRIFIC_DEF_PARMIN_PSWARM_GA4A 0 
#define TIRIFIC_DEF_PARMIN_PSWARM_GA4P -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_GA4D 0.0001  
#define TIRIFIC_DEF_PARMIN_PSWARM_AZ1P -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_AZ1W 0.0001  
#define TIRIFIC_DEF_PARMIN_PSWARM_AZ2P -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_AZ2W 0.0001  
#define TIRIFIC_DEF_PARMIN_PSWARM_INCL 0  
#define TIRIFIC_DEF_PARMIN_PSWARM_PA   -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_XPOS -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_YPOS -180  
#define TIRIFIC_DEF_PARMIN_PSWARM_VSYS -500
#define TIRIFIC_DEF_PARMIN_PSWARM_SDIS 0.0001  
#define TIRIFIC_DEF_PARMIN_PSWARM_CLNR 1 
#define TIRIFIC_DEF_PARMIN_PSWARM_VM0A 0  
#define TIRIFIC_DEF_PARMIN_PSWARM_VM1A 0  
#define TIRIFIC_DEF_PARMIN_PSWARM_VM1P -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_VM2A 0  
#define TIRIFIC_DEF_PARMIN_PSWARM_VM2P -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_VM3A 0  
#define TIRIFIC_DEF_PARMIN_PSWARM_VM3P -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_VM4A 0  
#define TIRIFIC_DEF_PARMIN_PSWARM_VM4P -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_WM0A 0
#define TIRIFIC_DEF_PARMIN_PSWARM_WM1A 0
#define TIRIFIC_DEF_PARMIN_PSWARM_WM1P -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_WM2A 0
#define TIRIFIC_DEF_PARMIN_PSWARM_WM2P -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_WM3A 0
#define TIRIFIC_DEF_PARMIN_PSWARM_WM3P -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_WM4A 0
#define TIRIFIC_DEF_PARMIN_PSWARM_WM4P -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_LS0  -10000
#define TIRIFIC_DEF_PARMIN_PSWARM_LC0  -10000
#define TIRIFIC_DEF_PARMIN_PSWARM_RO1A 0  
#define TIRIFIC_DEF_PARMIN_PSWARM_RO1P -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_RO2A 0  
#define TIRIFIC_DEF_PARMIN_PSWARM_RO2P -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_RO3A 0  
#define TIRIFIC_DEF_PARMIN_PSWARM_RO3P -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_RO4A 0  
#define TIRIFIC_DEF_PARMIN_PSWARM_RO4P -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_RA1A 0  
#define TIRIFIC_DEF_PARMIN_PSWARM_RA1P -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_RA2A 0  
#define TIRIFIC_DEF_PARMIN_PSWARM_RA2P -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_RA3A 0  
#define TIRIFIC_DEF_PARMIN_PSWARM_RA3P -360  
#define TIRIFIC_DEF_PARMIN_PSWARM_RA4A 0  
#define TIRIFIC_DEF_PARMIN_PSWARM_RA4P -360  

#define TIRIFIC_DEF_MODERATE_VROT TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_VRAD TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_VVER TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_DVRO TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_DVRA TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_DVVE TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_ZDRO TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_ZDRA TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_ZDVE TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_Z0   TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_SBR  TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_SM1A TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_SM1P TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_SM2A TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_SM2P TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_SM3A TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_SM3P TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_SM4A TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_SM4P TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_GA1A TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_GA1P TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_GA1D TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_GA2A TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_GA2P TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_GA2D TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_GA3A TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_GA3P TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_GA3D TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_GA4A TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_GA4P TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_GA4D TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_AZ1P TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_AZ1W TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_AZ2P TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_AZ2W TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_INCL TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_PA   TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_XPOS TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_YPOS TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_VSYS TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_SDIS TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_CLNR TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_VM0A TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_VM1A TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_VM1P TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_VM2A TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_VM2P TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_VM3A TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_VM3P TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_VM4A TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_VM4P TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_WM0A TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_WM1A TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_WM1P TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_WM2A TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_WM2P TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_WM3A TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_WM3P TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_WM4A TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_WM4P TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_LS0  TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_LC0  TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_RO1A TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_RO1P TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_RO2A TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_RO2P TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_RO3A TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_RO3P TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_RO4A TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_RO4P TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_RA1A TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_RA1P TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_RA2A TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_RA2P TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_RA3A TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_RA3P TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_RA4A TIRIFIC_DEF_MODERATE
#define TIRIFIC_DEF_MODERATE_RA4P TIRIFIC_DEF_MODERATE

#define TIRIFIC_DEF_DELSTART_VROT 3.
#define TIRIFIC_DEF_DELSTART_VRAD 3.
#define TIRIFIC_DEF_DELSTART_VVER 3.
#define TIRIFIC_DEF_DELSTART_DVRO 0.1
#define TIRIFIC_DEF_DELSTART_DVRA 0.1
#define TIRIFIC_DEF_DELSTART_DVVE 0.1
#define TIRIFIC_DEF_DELSTART_ZDRO 5.
#define TIRIFIC_DEF_DELSTART_ZDRA 5.
#define TIRIFIC_DEF_DELSTART_ZDVE 5.
#define TIRIFIC_DEF_DELSTART_Z0   5.
#define TIRIFIC_DEF_DELSTART_SBR  5E-6
#define TIRIFIC_DEF_DELSTART_SM1A 5E-6
#define TIRIFIC_DEF_DELSTART_SM1P 3.
#define TIRIFIC_DEF_DELSTART_SM2A 5E-6
#define TIRIFIC_DEF_DELSTART_SM2P 3.
#define TIRIFIC_DEF_DELSTART_SM3A 5E-6
#define TIRIFIC_DEF_DELSTART_SM3P 3.
#define TIRIFIC_DEF_DELSTART_SM4A 5E-6
#define TIRIFIC_DEF_DELSTART_SM4P 3.
#define TIRIFIC_DEF_DELSTART_GA1A 5E-6
#define TIRIFIC_DEF_DELSTART_GA1P 3.
#define TIRIFIC_DEF_DELSTART_GA1D 5.
#define TIRIFIC_DEF_DELSTART_GA2A 5E-6
#define TIRIFIC_DEF_DELSTART_GA2P 3.
#define TIRIFIC_DEF_DELSTART_GA2D 5.
#define TIRIFIC_DEF_DELSTART_GA3A 5E-6
#define TIRIFIC_DEF_DELSTART_GA3P 3.
#define TIRIFIC_DEF_DELSTART_GA3D 5.
#define TIRIFIC_DEF_DELSTART_GA4A 5E-6
#define TIRIFIC_DEF_DELSTART_GA4P 3.
#define TIRIFIC_DEF_DELSTART_GA4D 5.
#define TIRIFIC_DEF_DELSTART_AZ1P 3.
#define TIRIFIC_DEF_DELSTART_AZ1W 3.
#define TIRIFIC_DEF_DELSTART_AZ2P 3.
#define TIRIFIC_DEF_DELSTART_AZ2W 3.
#define TIRIFIC_DEF_DELSTART_INCL 3.
#define TIRIFIC_DEF_DELSTART_PA   3.
#define TIRIFIC_DEF_DELSTART_XPOS 5E-3
#define TIRIFIC_DEF_DELSTART_YPOS 5E-3
#define TIRIFIC_DEF_DELSTART_VSYS 1.
#define TIRIFIC_DEF_DELSTART_SDIS 1.
#define TIRIFIC_DEF_DELSTART_CLNR 1.
#define TIRIFIC_DEF_DELSTART_VM0A 3.
#define TIRIFIC_DEF_DELSTART_VM1A 3.
#define TIRIFIC_DEF_DELSTART_VM1P 3.
#define TIRIFIC_DEF_DELSTART_VM2A 3.
#define TIRIFIC_DEF_DELSTART_VM2P 3.
#define TIRIFIC_DEF_DELSTART_VM3A 3.
#define TIRIFIC_DEF_DELSTART_VM3P 3.
#define TIRIFIC_DEF_DELSTART_VM4A 3.
#define TIRIFIC_DEF_DELSTART_VM4P 3.
#define TIRIFIC_DEF_DELSTART_WM0A 5.
#define TIRIFIC_DEF_DELSTART_WM1A 5.
#define TIRIFIC_DEF_DELSTART_WM1P 3.
#define TIRIFIC_DEF_DELSTART_WM2A 5.
#define TIRIFIC_DEF_DELSTART_WM2P 3.
#define TIRIFIC_DEF_DELSTART_WM3A 5.
#define TIRIFIC_DEF_DELSTART_WM3P 3.
#define TIRIFIC_DEF_DELSTART_WM4A 5.
#define TIRIFIC_DEF_DELSTART_WM4P 3.
#define TIRIFIC_DEF_DELSTART_LS0  5.
#define TIRIFIC_DEF_DELSTART_LC0  5.
#define TIRIFIC_DEF_DELSTART_RO1A 3.
#define TIRIFIC_DEF_DELSTART_RO1P 3.
#define TIRIFIC_DEF_DELSTART_RO2A 3.
#define TIRIFIC_DEF_DELSTART_RO2P 3.
#define TIRIFIC_DEF_DELSTART_RO3A 3.
#define TIRIFIC_DEF_DELSTART_RO3P 3.
#define TIRIFIC_DEF_DELSTART_RO4A 3.
#define TIRIFIC_DEF_DELSTART_RO4P 3.
#define TIRIFIC_DEF_DELSTART_RA1A 3.
#define TIRIFIC_DEF_DELSTART_RA1P 3.
#define TIRIFIC_DEF_DELSTART_RA2A 3.
#define TIRIFIC_DEF_DELSTART_RA2P 3.
#define TIRIFIC_DEF_DELSTART_RA3A 3.
#define TIRIFIC_DEF_DELSTART_RA3P 3.
#define TIRIFIC_DEF_DELSTART_RA4A 3.
#define TIRIFIC_DEF_DELSTART_RA4P 3.      

#define TIRIFIC_DEF_DELEND_VROT 3.  
#define TIRIFIC_DEF_DELEND_VRAD 3.  
#define TIRIFIC_DEF_DELEND_VVER 3.  
#define TIRIFIC_DEF_DELEND_DVRO 0.1  
#define TIRIFIC_DEF_DELEND_DVRA 0.1  
#define TIRIFIC_DEF_DELEND_DVVE 0.1  
#define TIRIFIC_DEF_DELEND_ZDRO 5.  
#define TIRIFIC_DEF_DELEND_ZDRA 5.  
#define TIRIFIC_DEF_DELEND_ZDVE 5.  
#define TIRIFIC_DEF_DELEND_Z0   5.  
#define TIRIFIC_DEF_DELEND_SBR  5E-6  
#define TIRIFIC_DEF_DELEND_SM1A 5E-6  
#define TIRIFIC_DEF_DELEND_SM1P 3.  
#define TIRIFIC_DEF_DELEND_SM2A 5E-6  
#define TIRIFIC_DEF_DELEND_SM2P 3.  
#define TIRIFIC_DEF_DELEND_SM3A 5E-6  
#define TIRIFIC_DEF_DELEND_SM3P 3.  
#define TIRIFIC_DEF_DELEND_SM4A 5E-6  
#define TIRIFIC_DEF_DELEND_SM4P 3.  
#define TIRIFIC_DEF_DELEND_GA1A 5E-6  
#define TIRIFIC_DEF_DELEND_GA1P 3.  
#define TIRIFIC_DEF_DELEND_GA1D 5.  
#define TIRIFIC_DEF_DELEND_GA2A 5E-6  
#define TIRIFIC_DEF_DELEND_GA2P 3.  
#define TIRIFIC_DEF_DELEND_GA2D 5.  
#define TIRIFIC_DEF_DELEND_GA3A 5E-6  
#define TIRIFIC_DEF_DELEND_GA3P 3.  
#define TIRIFIC_DEF_DELEND_GA3D 5.  
#define TIRIFIC_DEF_DELEND_GA4A 5E-6  
#define TIRIFIC_DEF_DELEND_GA4P 3.  
#define TIRIFIC_DEF_DELEND_GA4D 5.  
#define TIRIFIC_DEF_DELEND_AZ1P 3.  
#define TIRIFIC_DEF_DELEND_AZ1W 3.  
#define TIRIFIC_DEF_DELEND_AZ2P 3.  
#define TIRIFIC_DEF_DELEND_AZ2W 3.  
#define TIRIFIC_DEF_DELEND_INCL 3.  
#define TIRIFIC_DEF_DELEND_PA   3.  
#define TIRIFIC_DEF_DELEND_XPOS 5E-3  
#define TIRIFIC_DEF_DELEND_YPOS 5E-3  
#define TIRIFIC_DEF_DELEND_VSYS 1.  
#define TIRIFIC_DEF_DELEND_SDIS 1.  
#define TIRIFIC_DEF_DELEND_CLNR 1.  
#define TIRIFIC_DEF_DELEND_VM0A 3.  
#define TIRIFIC_DEF_DELEND_VM1A 3.  
#define TIRIFIC_DEF_DELEND_VM1P 3.  
#define TIRIFIC_DEF_DELEND_VM2A 3.  
#define TIRIFIC_DEF_DELEND_VM2P 3.  
#define TIRIFIC_DEF_DELEND_VM3A 3.  
#define TIRIFIC_DEF_DELEND_VM3P 3.  
#define TIRIFIC_DEF_DELEND_VM4A 3.  
#define TIRIFIC_DEF_DELEND_VM4P 3.  
#define TIRIFIC_DEF_DELEND_WM0A 5.  
#define TIRIFIC_DEF_DELEND_WM1A 5.  
#define TIRIFIC_DEF_DELEND_WM1P 3.  
#define TIRIFIC_DEF_DELEND_WM2A 5.  
#define TIRIFIC_DEF_DELEND_WM2P 3.  
#define TIRIFIC_DEF_DELEND_WM3A 5.  
#define TIRIFIC_DEF_DELEND_WM3P 3.  
#define TIRIFIC_DEF_DELEND_WM4A 5.  
#define TIRIFIC_DEF_DELEND_WM4P 3.  
#define TIRIFIC_DEF_DELEND_LS0  5.  
#define TIRIFIC_DEF_DELEND_LC0  5.  
#define TIRIFIC_DEF_DELEND_RO1A 3.  
#define TIRIFIC_DEF_DELEND_RO1P 3.  
#define TIRIFIC_DEF_DELEND_RO2A 3.  
#define TIRIFIC_DEF_DELEND_RO2P 3.  
#define TIRIFIC_DEF_DELEND_RO3A 3.  
#define TIRIFIC_DEF_DELEND_RO3P 3.  
#define TIRIFIC_DEF_DELEND_RO4A 3.  
#define TIRIFIC_DEF_DELEND_RO4P 3.  
#define TIRIFIC_DEF_DELEND_RA1A 3.  
#define TIRIFIC_DEF_DELEND_RA1P 3.  
#define TIRIFIC_DEF_DELEND_RA2A 3.  
#define TIRIFIC_DEF_DELEND_RA2P 3.  
#define TIRIFIC_DEF_DELEND_RA3A 3.  
#define TIRIFIC_DEF_DELEND_RA3P 3.  
#define TIRIFIC_DEF_DELEND_RA4A 3.  
#define TIRIFIC_DEF_DELEND_RA4P 3.      

#define TIRIFIC_DEF_ITESTART_VROT TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_VRAD TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_VVER TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_DVRO TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_DVRA TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_DVVE TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_ZDRO TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_ZDRA TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_ZDVE TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_Z0   TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_SBR  TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_SM1A TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_SM1P TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_SM2A TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_SM2P TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_SM3A TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_SM3P TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_SM4A TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_SM4P TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_GA1A TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_GA1P TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_GA1D TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_GA2A TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_GA2P TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_GA2D TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_GA3A TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_GA3P TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_GA3D TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_GA4A TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_GA4P TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_GA4D TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_AZ1P TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_AZ1W TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_AZ2P TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_AZ2W TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_INCL TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_PA   TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_XPOS TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_YPOS TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_VSYS TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_SDIS TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_CLNR TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_VM0A TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_VM1A TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_VM1P TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_VM2A TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_VM2P TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_VM3A TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_VM3P TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_VM4A TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_VM4P TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_WM0A TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_WM1A TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_WM1P TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_WM2A TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_WM2P TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_WM3A TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_WM3P TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_WM4A TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_WM4P TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_LS0  TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_LC0  TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_RO1A TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_RO1P TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_RO2A TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_RO2P TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_RO3A TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_RO3P TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_RO4A TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_RO4P TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_RA1A TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_RA1P TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_RA2A TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_RA2P TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_RA3A TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_RA3P TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_RA4A TIRIFIC_DEF_ITESTART
#define TIRIFIC_DEF_ITESTART_RA4P TIRIFIC_DEF_ITESTART

#define TIRIFIC_DEF_ITEEND_VROT TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_VRAD TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_VVER TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_DVRO TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_DVRA TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_DVVE TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_ZDRO TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_ZDRA TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_ZDVE TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_Z0   TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_SBR  TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_SM1A TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_SM1P TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_SM2A TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_SM2P TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_SM3A TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_SM3P TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_SM4A TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_SM4P TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_GA1A TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_GA1P TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_GA1D TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_GA2A TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_GA2P TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_GA2D TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_GA3A TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_GA3P TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_GA3D TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_GA4A TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_GA4P TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_GA4D TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_AZ1P TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_AZ1W TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_AZ2P TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_AZ2W TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_INCL TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_PA   TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_XPOS TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_YPOS TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_VSYS TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_SDIS TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_CLNR TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_VM0A TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_VM1A TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_VM1P TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_VM2A TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_VM2P TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_VM3A TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_VM3P TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_VM4A TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_VM4P TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_WM0A TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_WM1A TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_WM1P TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_WM2A TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_WM2P TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_WM3A TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_WM3P TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_WM4A TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_WM4P TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_LS0  TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_LC0  TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_RO1A TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_RO1P TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_RO2A TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_RO2P TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_RO3A TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_RO3P TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_RO4A TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_RO4P TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_RA1A TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_RA1P TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_RA2A TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_RA2P TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_RA3A TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_RA3P TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_RA4A TIRIFIC_DEF_ITEEND
#define TIRIFIC_DEF_ITEEND_RA4P TIRIFIC_DEF_ITEEND

#define TIRIFIC_DEF_SATDELT_VROT 0.2 
#define TIRIFIC_DEF_SATDELT_VRAD 0.2 
#define TIRIFIC_DEF_SATDELT_VVER 0.2 
#define TIRIFIC_DEF_SATDELT_DVRO 0.2 
#define TIRIFIC_DEF_SATDELT_DVRA 0.02 
#define TIRIFIC_DEF_SATDELT_DVVE 0.02 
#define TIRIFIC_DEF_SATDELT_ZDRO 0.5 
#define TIRIFIC_DEF_SATDELT_ZDRA 0.5 
#define TIRIFIC_DEF_SATDELT_ZDVE 0.5 
#define TIRIFIC_DEF_SATDELT_Z0   1 
#define TIRIFIC_DEF_SATDELT_SBR  5E-7 
#define TIRIFIC_DEF_SATDELT_SM1A 5E-7 
#define TIRIFIC_DEF_SATDELT_SM1P 0.2 
#define TIRIFIC_DEF_SATDELT_SM2A 5E-7 
#define TIRIFIC_DEF_SATDELT_SM2P 0.2 
#define TIRIFIC_DEF_SATDELT_SM3A 5E-7 
#define TIRIFIC_DEF_SATDELT_SM3P 0.2 
#define TIRIFIC_DEF_SATDELT_SM4A 5E-7 
#define TIRIFIC_DEF_SATDELT_SM4P 0.2 
#define TIRIFIC_DEF_SATDELT_GA1A 5E-7 
#define TIRIFIC_DEF_SATDELT_GA1P 0.2 
#define TIRIFIC_DEF_SATDELT_GA1D 1. 
#define TIRIFIC_DEF_SATDELT_GA2A 5E-7 
#define TIRIFIC_DEF_SATDELT_GA2P 0.2 
#define TIRIFIC_DEF_SATDELT_GA2D 1. 
#define TIRIFIC_DEF_SATDELT_GA3A 5E-7 
#define TIRIFIC_DEF_SATDELT_GA3P 0.2 
#define TIRIFIC_DEF_SATDELT_GA3D 1. 
#define TIRIFIC_DEF_SATDELT_GA4A 5E-7 
#define TIRIFIC_DEF_SATDELT_GA4P 0.2 
#define TIRIFIC_DEF_SATDELT_GA4D 1. 
#define TIRIFIC_DEF_SATDELT_AZ1P 0.2 
#define TIRIFIC_DEF_SATDELT_AZ1W 0.2 
#define TIRIFIC_DEF_SATDELT_AZ2P 0.2 
#define TIRIFIC_DEF_SATDELT_AZ2W 0.2 
#define TIRIFIC_DEF_SATDELT_INCL 0.2
#define TIRIFIC_DEF_SATDELT_PA   0.2 
#define TIRIFIC_DEF_SATDELT_XPOS 2E-4 
#define TIRIFIC_DEF_SATDELT_YPOS 2E-4 
#define TIRIFIC_DEF_SATDELT_VSYS 0.05 
#define TIRIFIC_DEF_SATDELT_SDIS 0.05 
#define TIRIFIC_DEF_SATDELT_CLNR 0.2 
#define TIRIFIC_DEF_SATDELT_VM0A 0.2 
#define TIRIFIC_DEF_SATDELT_VM1A 0.2 
#define TIRIFIC_DEF_SATDELT_VM1P 0.2 
#define TIRIFIC_DEF_SATDELT_VM2A 0.2 
#define TIRIFIC_DEF_SATDELT_VM2P 0.2 
#define TIRIFIC_DEF_SATDELT_VM3A 0.2 
#define TIRIFIC_DEF_SATDELT_VM3P 0.2 
#define TIRIFIC_DEF_SATDELT_VM4A 0.2 
#define TIRIFIC_DEF_SATDELT_VM4P 0.2 
#define TIRIFIC_DEF_SATDELT_WM0A 0.5 
#define TIRIFIC_DEF_SATDELT_WM1A 0.5 
#define TIRIFIC_DEF_SATDELT_WM1P 0.2 
#define TIRIFIC_DEF_SATDELT_WM2A 0.5 
#define TIRIFIC_DEF_SATDELT_WM2P 0.2 
#define TIRIFIC_DEF_SATDELT_WM3A 0.5 
#define TIRIFIC_DEF_SATDELT_WM3P 0.2 
#define TIRIFIC_DEF_SATDELT_WM4A 0.5 
#define TIRIFIC_DEF_SATDELT_WM4P 0.2 
#define TIRIFIC_DEF_SATDELT_LS0  0.5 
#define TIRIFIC_DEF_SATDELT_LC0  0.5 
#define TIRIFIC_DEF_SATDELT_RO1A 0.2 
#define TIRIFIC_DEF_SATDELT_RO1P 0.2 
#define TIRIFIC_DEF_SATDELT_RO2A 0.2 
#define TIRIFIC_DEF_SATDELT_RO2P 0.2 
#define TIRIFIC_DEF_SATDELT_RO3A 0.2 
#define TIRIFIC_DEF_SATDELT_RO3P 0.2 
#define TIRIFIC_DEF_SATDELT_RO4A 0.2 
#define TIRIFIC_DEF_SATDELT_RO4P 0.2 
#define TIRIFIC_DEF_SATDELT_RA1A 0.2 
#define TIRIFIC_DEF_SATDELT_RA1P 0.2 
#define TIRIFIC_DEF_SATDELT_RA2A 0.2 
#define TIRIFIC_DEF_SATDELT_RA2P 0.2 
#define TIRIFIC_DEF_SATDELT_RA3A 0.2 
#define TIRIFIC_DEF_SATDELT_RA3P 0.2 
#define TIRIFIC_DEF_SATDELT_RA4A 0.2 
#define TIRIFIC_DEF_SATDELT_RA4P 0.2     

#define TIRIFIC_DEF_MINDELTA_VROT 0.05 
#define TIRIFIC_DEF_MINDELTA_VRAD 0.05 
#define TIRIFIC_DEF_MINDELTA_VVER 0.05 
#define TIRIFIC_DEF_MINDELTA_DVRO 0.05 
#define TIRIFIC_DEF_MINDELTA_DVRA 0.005
#define TIRIFIC_DEF_MINDELTA_DVVE 0.005
#define TIRIFIC_DEF_MINDELTA_ZDRO 0.125 
#define TIRIFIC_DEF_MINDELTA_ZDRA 0.125 
#define TIRIFIC_DEF_MINDELTA_ZDVE 0.125 
#define TIRIFIC_DEF_MINDELTA_Z0   0.25   
#define TIRIFIC_DEF_MINDELTA_SBR  1.25E-7
#define TIRIFIC_DEF_MINDELTA_SM1A 1.25E-7
#define TIRIFIC_DEF_MINDELTA_SM1P 0.05 
#define TIRIFIC_DEF_MINDELTA_SM2A 1.25E-7
#define TIRIFIC_DEF_MINDELTA_SM2P 0.05 
#define TIRIFIC_DEF_MINDELTA_SM3A 1.25E-7
#define TIRIFIC_DEF_MINDELTA_SM3P 0.05 
#define TIRIFIC_DEF_MINDELTA_SM4A 1.25E-7
#define TIRIFIC_DEF_MINDELTA_SM4P 0.05 
#define TIRIFIC_DEF_MINDELTA_GA1A 1.25E-7
#define TIRIFIC_DEF_MINDELTA_GA1P 0.05 
#define TIRIFIC_DEF_MINDELTA_GA1D 0.25  
#define TIRIFIC_DEF_MINDELTA_GA2A 1.25E-7
#define TIRIFIC_DEF_MINDELTA_GA2P 0.05 
#define TIRIFIC_DEF_MINDELTA_GA2D 0.25  
#define TIRIFIC_DEF_MINDELTA_GA3A 1.25E-7
#define TIRIFIC_DEF_MINDELTA_GA3P 0.05 
#define TIRIFIC_DEF_MINDELTA_GA3D 0.25  
#define TIRIFIC_DEF_MINDELTA_GA4A 1.25E-7
#define TIRIFIC_DEF_MINDELTA_GA4P 0.05 
#define TIRIFIC_DEF_MINDELTA_GA4D 0.25  
#define TIRIFIC_DEF_MINDELTA_AZ1P 0.05 
#define TIRIFIC_DEF_MINDELTA_AZ1W 0.05 
#define TIRIFIC_DEF_MINDELTA_AZ2P 0.05 
#define TIRIFIC_DEF_MINDELTA_AZ2W 0.05 
#define TIRIFIC_DEF_MINDELTA_INCL 0.05
#define TIRIFIC_DEF_MINDELTA_PA   0.05
#define TIRIFIC_DEF_MINDELTA_XPOS 5E-5
#define TIRIFIC_DEF_MINDELTA_YPOS 5E-5
#define TIRIFIC_DEF_MINDELTA_VSYS 0.0125
#define TIRIFIC_DEF_MINDELTA_SDIS 0.0125
#define TIRIFIC_DEF_MINDELTA_CLNR 0.05 
#define TIRIFIC_DEF_MINDELTA_VM0A 0.05 
#define TIRIFIC_DEF_MINDELTA_VM1A 0.05 
#define TIRIFIC_DEF_MINDELTA_VM1P 0.05 
#define TIRIFIC_DEF_MINDELTA_VM2A 0.05 
#define TIRIFIC_DEF_MINDELTA_VM2P 0.05 
#define TIRIFIC_DEF_MINDELTA_VM3A 0.05 
#define TIRIFIC_DEF_MINDELTA_VM3P 0.05 
#define TIRIFIC_DEF_MINDELTA_VM4A 0.05 
#define TIRIFIC_DEF_MINDELTA_VM4P 0.05 
#define TIRIFIC_DEF_MINDELTA_WM0A 0.125 
#define TIRIFIC_DEF_MINDELTA_WM1A 0.125 
#define TIRIFIC_DEF_MINDELTA_WM1P 0.05 
#define TIRIFIC_DEF_MINDELTA_WM2A 0.125 
#define TIRIFIC_DEF_MINDELTA_WM2P 0.05 
#define TIRIFIC_DEF_MINDELTA_WM3A 0.125 
#define TIRIFIC_DEF_MINDELTA_WM3P 0.05 
#define TIRIFIC_DEF_MINDELTA_WM4A 0.125 
#define TIRIFIC_DEF_MINDELTA_WM4P 0.05 
#define TIRIFIC_DEF_MINDELTA_LS0  0.125 
#define TIRIFIC_DEF_MINDELTA_LC0  0.125 
#define TIRIFIC_DEF_MINDELTA_RO1A 0.05 
#define TIRIFIC_DEF_MINDELTA_RO1P 0.05 
#define TIRIFIC_DEF_MINDELTA_RO2A 0.05 
#define TIRIFIC_DEF_MINDELTA_RO2P 0.05 
#define TIRIFIC_DEF_MINDELTA_RO3A 0.05 
#define TIRIFIC_DEF_MINDELTA_RO3P 0.05 
#define TIRIFIC_DEF_MINDELTA_RO4A 0.05 
#define TIRIFIC_DEF_MINDELTA_RO4P 0.05 
#define TIRIFIC_DEF_MINDELTA_RA1A 0.05 
#define TIRIFIC_DEF_MINDELTA_RA1P 0.05 
#define TIRIFIC_DEF_MINDELTA_RA2A 0.05 
#define TIRIFIC_DEF_MINDELTA_RA2P 0.05 
#define TIRIFIC_DEF_MINDELTA_RA3A 0.05 
#define TIRIFIC_DEF_MINDELTA_RA3P 0.05 
#define TIRIFIC_DEF_MINDELTA_RA4A 0.05 
#define TIRIFIC_DEF_MINDELTA_RA4P 0.05 

/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* MACROS */
/* ------------------------------------------------------------ */



/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* TYPEDEFS */
/* ------------------------------------------------------------ */



/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* STRUCTS */
/* ------------------------------------------------------------ */



/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/* FUNCTION DECLARATIONS */
/* ------------------------------------------------------------ */

/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ */
/**
  @fn int tirific_defaults_fitdefromident(int parnum, int nur, int ndisk, int fitmode, int fpar, double *value)
  @brief Get default value (world coordinates) from parameter number

  @param parnum (int)    parameter number
  @param nur    (int)    number of rings
  @param ndisk  (int)    number of disks
  @param fpar   (int)    identifyer of which parameter
  @param value   (double) output, must be allocated

  @return (success) int tirific_defaults_fitdefromident: 0
  (error) 1

*/
/* ------------------------------------------------------------ */
int tirific_defaults_fitdefromident(int parnum, int nur, int ndisk, int fpar, int fitmode, double *value);



/* ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++ 
   ------------------------------------------------------------ */

/* Include guard */
#endif
